🔖 [Table of Contents](../README.md) / [FAQ](README.md)


# Does Zrb Have a Scheduler?

No, but you can use `RecurringTask` and `TimeWatcher`


# How To Make A Scheduled Task?

There are some [tricks](../tutorials/running-task-by-schedule.md) you can use.

For example, you can use:

- RecurringTask
- Infinite loop
- Cronjob
- Orchestrator like Airflow.

🔖 [Table of Contents](../README.md) / [FAQ](README.md)
